==> qt6-sensors_6.2.4.orig.tar.xz: qtsensors-everywhere-src-6.2.4/src/sensorsquick/qmlgyroscope_p.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QMLGYROSCOPE_P_H
#define QMLGYROSCOPE_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qmlsensor_p.h"

QT_BEGIN_NAMESPACE

class QGyroscope;

class Q_SENSORSQUICK_PRIVATE_EXPORT QmlGyroscope : public QmlSensor
{
    Q_OBJECT
    QML_NAMED_ELEMENT(Gyroscope)
    QML_ADDED_IN_VERSION(5,0)
public:
    explicit QmlGyroscope(QObject *parent = 0);
    ~QmlGyroscope();

    QSensor *sensor() const override;

private:
    QGyroscope *m_sensor;
    QmlSensorReading *createReading() const override;
};

class Q_SENSORSQUICK_PRIVATE_EXPORT QmlGyroscopeReading : public QmlSensorReading
{
    Q_OBJECT
    Q_PROPERTY(qreal x READ x NOTIFY xChanged BINDABLE bindableX)
    Q_PROPERTY(qreal y READ y NOTIFY yChanged BINDABLE bindableY)
    Q_PROPERTY(qreal z READ z NOTIFY zChanged BINDABLE bindableZ)
    QML_NAMED_ELEMENT(GyroscopeReading)
    QML_UNCREATABLE("Cannot create GyroscopeReading")
    QML_ADDED_IN_VERSION(5,0)
public:
    explicit QmlGyroscopeReading(QGyroscope *sensor);
    ~QmlGyroscopeReading();

    qreal x() const;
    QBindable<qreal> bindableX() const;
    qreal y() const;
    QBindable<qreal> bindableY() const;
    qreal z() const;
    QBindable<qreal> bindableZ() const;

Q_SIGNALS:
    void xChanged();
    void yChanged();
    void zChanged();

private:
    QSensorReading *reading() const override;
    void readingUpdate() override;
    QGyroscope *m_sensor;
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_x, &QmlGyroscopeReading::xChanged)
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_y, &QmlGyroscopeReading::yChanged)
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_z, &QmlGyroscopeReading::zChanged)
};

QT_END_NAMESPACE
#endif

==> qt6-sensors_6.10.2.orig.tar.xz: qtsensors-everywhere-src-6.10.2/src/sensorsquick/qmlgyroscope_p.h <==
// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QMLGYROSCOPE_P_H
#define QMLGYROSCOPE_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qmlsensor_p.h"

QT_BEGIN_NAMESPACE

class QGyroscope;

class Q_SENSORSQUICK_EXPORT QmlGyroscope : public QmlSensor
{
    Q_OBJECT
    QML_NAMED_ELEMENT(Gyroscope)
    QML_ADDED_IN_VERSION(5,0)
public:
    explicit QmlGyroscope(QObject *parent = 0);
    ~QmlGyroscope();

    QSensor *sensor() const override;

private:
    QGyroscope *m_sensor;
    QmlSensorReading *createReading() const override;
};

class Q_SENSORSQUICK_EXPORT QmlGyroscopeReading : public QmlSensorReading
{
    Q_OBJECT
    Q_PROPERTY(qreal x READ x NOTIFY xChanged BINDABLE bindableX)
    Q_PROPERTY(qreal y READ y NOTIFY yChanged BINDABLE bindableY)
    Q_PROPERTY(qreal z READ z NOTIFY zChanged BINDABLE bindableZ)
    QML_NAMED_ELEMENT(GyroscopeReading)
    QML_UNCREATABLE("Cannot create GyroscopeReading")
    QML_ADDED_IN_VERSION(5,0)
public:
    explicit QmlGyroscopeReading(QGyroscope *sensor);
    ~QmlGyroscopeReading();

    qreal x() const;
    QBindable<qreal> bindableX() const;
    qreal y() const;
    QBindable<qreal> bindableY() const;
    qreal z() const;
    QBindable<qreal> bindableZ() const;

Q_SIGNALS:
    void xChanged();
    void yChanged();
    void zChanged();

private:
    QSensorReading *reading() const override;
    void readingUpdate() override;
    QGyroscope *m_sensor;
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_x, &QmlGyroscopeReading::xChanged)
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_y, &QmlGyroscopeReading::yChanged)
    Q_OBJECT_BINDABLE_PROPERTY(QmlGyroscopeReading, qreal,
                               m_z, &QmlGyroscopeReading::zChanged)
};

QT_END_NAMESPACE
#endif
